@@ -63,6 +63,7 @@ struct _DzlAnimation
   GdkFrameClock     *frame_clock;         /* An optional frame-clock for sync. */
   GDestroyNotify     notify;              /* Notify callback */
   gpointer           notify_data;         /* Data for notify */
+  guint              stop_called : 1;
 };
 
 G_DEFINE_TYPE (DzlAnimation, dzl_animation, G_TYPE_INITIALLY_UNOWNED)
@@ -629,15 +630,17 @@ dzl_animation_start (DzlAnimation *animation)
       animation->begin_time = gdk_frame_clock_get_frame_time (animation->frame_clock);
       animation->end_time = animation->begin_time + (animation->duration_msec * 1000L);
       animation->tween_handler =
-        g_signal_connect (animation->frame_clock,
-                          "update",
-                          G_CALLBACK (dzl_animation_widget_tick_cb),
-                          animation);
+        g_signal_connect_object (animation->frame_clock,
+                                 "update",
+                                 G_CALLBACK (dzl_animation_widget_tick_cb),
+                                 animation,
+                                 0);
       animation->after_paint_handler =
-        g_signal_connect (animation->frame_clock,
-                          "after-paint",
-                          G_CALLBACK (dzl_animation_widget_after_paint_cb),
-                          animation);
+        g_signal_connect_object (animation->frame_clock,
+                                 "after-paint",
+                                 G_CALLBACK (dzl_animation_widget_after_paint_cb),
+                                 animation,
+                                 0);
       gdk_frame_clock_begin_updating (animation->frame_clock);
     }
   else
@@ -685,6 +688,11 @@ dzl_animation_stop (DzlAnimation *animation)
   if (animation == NULL)
     return;
 
+  g_return_if_fail (DZL_IS_ANIMATION (animation));
+  g_return_if_fail (animation->stop_called == FALSE);
+
+  animation->stop_called = TRUE;
+
   if (animation->tween_handler)
     {
       if (animation->frame_clock)
