@@ -21,16 +21,18 @@
 
 #include "dzl-version-macros.h"
 
-#include "dzl-graph-view.h"
+#include "graphing/dzl-graph-view.h"
 
 G_BEGIN_DECLS
 
 #define DZL_TYPE_CPU_GRAPH (dzl_cpu_graph_get_type())
 
+DZL_AVAILABLE_IN_ALL
 G_DECLARE_FINAL_TYPE (DzlCpuGraph, dzl_cpu_graph, DZL, CPU_GRAPH, DzlGraphView)
 
 DZL_AVAILABLE_IN_ALL
-GtkWidget *dzl_cpu_graph_new (void);
+GtkWidget *dzl_cpu_graph_new_full (gint64 timespan,
+                                   guint  max_samples);
 
 G_END_DECLS
 
