@@ -39,11 +39,15 @@ typedef struct
 
   GtkScrolledWindow     *scroller;
   GtkStack              *page_stack;
-  GtkStackSwitcher      *page_stack_sidebar;
+  GtkStackSidebar       *page_stack_sidebar;
   GtkSearchEntry        *search_entry;
   GtkStack              *subpage_stack;
+  GtkBox                *sidebar;
+  GtkStackSwitcher      *top_stack_switcher;
 
   guint                  last_widget_id;
+
+  guint                  use_sidebar : 1;
 } DzlPreferencesViewPrivate;
 
 typedef struct
@@ -59,6 +63,14 @@ G_DEFINE_TYPE_WITH_CODE (DzlPreferencesView, dzl_preferences_view, GTK_TYPE_BIN,
                          G_ADD_PRIVATE (DzlPreferencesView)
                          G_IMPLEMENT_INTERFACE (DZL_TYPE_PREFERENCES, dzl_preferences_iface_init))
 
+enum {
+  PROP_0,
+  PROP_USE_SIDEBAR,
+  N_PROPS
+};
+
+static GParamSpec *properties [N_PROPS];
+
 static void
 tracked_widget_free (gpointer data)
 {
@@ -132,7 +144,7 @@ dzl_preferences_view_refilter (DzlPreferencesView *self,
                          dzl_preferences_view_refilter_cb,
                          spec);
 
-  g_clear_pointer (&spec, dzl_pattern_spec_unref);
+  dzl_clear_pointer (&spec, dzl_pattern_spec_unref);
 }
 
 static gint
@@ -209,13 +221,51 @@ dzl_preferences_view_finalize (GObject *object)
   DzlPreferencesView *self = (DzlPreferencesView *)object;
   DzlPreferencesViewPrivate *priv = dzl_preferences_view_get_instance_private (self);
 
-  g_clear_pointer (&priv->pages, g_sequence_free);
-  g_clear_pointer (&priv->widgets, g_hash_table_unref);
+  dzl_clear_pointer (&priv->pages, g_sequence_free);
+  dzl_clear_pointer (&priv->widgets, g_hash_table_unref);
   g_clear_object (&priv->actions);
 
   G_OBJECT_CLASS (dzl_preferences_view_parent_class)->finalize (object);
 }
 
+static void
+dzl_preferences_view_get_property (GObject    *object,
+                                   guint       prop_id,
+                                   GValue     *value,
+                                   GParamSpec *pspec)
+{
+  DzlPreferencesView *self = DZL_PREFERENCES_VIEW (object);
+
+  switch (prop_id)
+    {
+    case PROP_USE_SIDEBAR:
+      g_value_set_boolean (value, dzl_preferences_view_get_use_sidebar (self));
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+    }
+}
+
+static void
+dzl_preferences_view_set_property (GObject      *object,
+                                   guint         prop_id,
+                                   const GValue *value,
+                                   GParamSpec   *pspec)
+{
+  DzlPreferencesView *self = DZL_PREFERENCES_VIEW (object);
+
+  switch (prop_id)
+    {
+    case PROP_USE_SIDEBAR:
+      dzl_preferences_view_set_use_sidebar (self, g_value_get_boolean (value));
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+    }
+}
+
 static void
 dzl_preferences_view_class_init (DzlPreferencesViewClass *klass)
 {
@@ -223,6 +273,8 @@ dzl_preferences_view_class_init (DzlPreferencesViewClass *klass)
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   object_class->finalize = dzl_preferences_view_finalize;
+  object_class->get_property = dzl_preferences_view_get_property;
+  object_class->set_property = dzl_preferences_view_set_property;
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/dazzle/ui/dzl-preferences-view.ui");
   gtk_widget_class_set_css_name (widget_class, "dzlpreferencesview");
@@ -230,7 +282,18 @@ dzl_preferences_view_class_init (DzlPreferencesViewClass *klass)
   gtk_widget_class_bind_template_child_private (widget_class, DzlPreferencesView, page_stack_sidebar);
   gtk_widget_class_bind_template_child_private (widget_class, DzlPreferencesView, scroller);
   gtk_widget_class_bind_template_child_private (widget_class, DzlPreferencesView, search_entry);
+  gtk_widget_class_bind_template_child_private (widget_class, DzlPreferencesView, sidebar);
   gtk_widget_class_bind_template_child_private (widget_class, DzlPreferencesView, subpage_stack);
+  gtk_widget_class_bind_template_child_private (widget_class, DzlPreferencesView, top_stack_switcher);
+
+  properties [PROP_USE_SIDEBAR] =
+    g_param_spec_boolean ("use-sidebar",
+                          "Use Sidebar",
+                          "Use Sidebar",
+                          FALSE,
+                          (G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS));
+
+  g_object_class_install_properties (object_class, N_PROPS, properties);
 }
 
 static void
@@ -299,6 +362,8 @@ dzl_preferences_view_init (DzlPreferencesView *self)
     { "go-back", go_back_activate },
   };
 
+  priv->use_sidebar = TRUE;
+
   gtk_widget_init_template (GTK_WIDGET (self));
 
   g_signal_connect_object (priv->search_entry,
@@ -508,6 +573,8 @@ dzl_preferences_view_add_radio (DzlPreferences *preferences,
 
       if (variant == NULL)
         g_warning ("%s", error->message);
+      else
+        g_variant_ref_sink (variant);
     }
 
   widget = g_object_new (DZL_TYPE_PREFERENCES_SWITCH,
@@ -584,6 +651,8 @@ dzl_preferences_view_add_switch (DzlPreferences *preferences,
 
       if (variant == NULL)
         g_warning ("%s", error->message);
+      else
+        g_variant_ref_sink (variant);
     }
 
   widget = g_object_new (DZL_TYPE_PREFERENCES_SWITCH,
@@ -959,3 +1028,34 @@ dzl_preferences_view_new (void)
 {
   return g_object_new (DZL_TYPE_PREFERENCES_VIEW, NULL);
 }
+
+gboolean
+dzl_preferences_view_get_use_sidebar (DzlPreferencesView *self)
+{
+  DzlPreferencesViewPrivate *priv = dzl_preferences_view_get_instance_private (self);
+
+  g_return_val_if_fail (DZL_IS_PREFERENCES_VIEW (self), FALSE);
+
+  return priv->use_sidebar;
+}
+
+void
+dzl_preferences_view_set_use_sidebar (DzlPreferencesView *self,
+                                      gboolean            use_sidebar)
+{
+  DzlPreferencesViewPrivate *priv = dzl_preferences_view_get_instance_private (self);
+
+  g_return_if_fail (DZL_IS_PREFERENCES_VIEW (self));
+
+  use_sidebar = !!use_sidebar;
+
+  if (priv->use_sidebar != use_sidebar)
+    {
+      priv->use_sidebar = use_sidebar;
+
+      gtk_widget_set_visible (GTK_WIDGET (priv->sidebar), use_sidebar);
+      gtk_widget_set_visible (GTK_WIDGET (priv->top_stack_switcher), !use_sidebar);
+
+      g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_USE_SIDEBAR]);
+    }
+}
