@@ -562,3 +562,13 @@ dzl_file_chooser_entry_set_file (DzlFileChooserEntry *self,
 
   g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_FILE]);
 }
+
+GtkWidget *
+dzl_file_chooser_entry_new (const gchar          *title,
+                            GtkFileChooserAction  action)
+{
+  return g_object_new (DZL_TYPE_FILE_CHOOSER_ENTRY,
+                       "title", title,
+                       "action", action,
+                       NULL);
+}
